// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: adb_host.proto
// Protobuf C++ Version: 7.35.0

#include "adb_host.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::adb::proto::Device
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::Devices
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::AdbServerStatus
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace adb {
namespace proto {
class Device::_Internal {
 public:
  using HasBits = decltype(::std::declval<Device>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Device, _impl_._has_bits_);
};

constexpr Device::ParseTableT_ Device::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Device, _impl_._has_bits_),
      0, // no _extensions_
      10, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294966272,  // skipmap
      offsetof(ParseTableT_, field_entries),
      10,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::Device>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string serial = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.serial_)}},
      // .adb.proto.ConnectionState state = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Device, _impl_.state_), 5>(),
       {16, 5, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.state_)}},
      // string bus_address = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.bus_address_)}},
      // string product = 4;
      {::_pbi::TcParser::FastUS1,
       {34, 2, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.product_)}},
      // string model = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 3, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.model_)}},
      // string device = 6;
      {::_pbi::TcParser::FastUS1,
       {50, 4, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.device_)}},
      // .adb.proto.ConnectionType connection_type = 7;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Device, _impl_.connection_type_), 6>(),
       {56, 6, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.connection_type_)}},
      // int64 negotiated_speed = 8;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Device, _impl_.negotiated_speed_), 7>(),
       {64, 7, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.negotiated_speed_)}},
      // int64 max_speed = 9;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Device, _impl_.max_speed_), 8>(),
       {72, 8, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.max_speed_)}},
      // int64 transport_id = 10;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Device, _impl_.transport_id_), 9>(),
       {80, 9, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.transport_id_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string serial = 1;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.serial_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .adb.proto.ConnectionState state = 2;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.state_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // string bus_address = 3;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.bus_address_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string product = 4;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.product_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string model = 5;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.model_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string device = 6;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.device_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .adb.proto.ConnectionType connection_type = 7;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.connection_type_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // int64 negotiated_speed = 8;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.negotiated_speed_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // int64 max_speed = 9;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.max_speed_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // int64 transport_id = 10;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.transport_id_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    }},
    // no aux_entries
    {{
      "\20\6\0\13\7\5\6\0\0\0\0\0\0\0\0\0"
      "adb.proto.Device"
      "serial"
      "bus_address"
      "product"
      "model"
      "device"
    }},
  };
}


inline constexpr Device::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        serial_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        bus_address_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        product_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        model_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        device_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        state_{static_cast< ::adb::proto::ConnectionState >(0)},
        connection_type_{static_cast< ::adb::proto::ConnectionType >(0)},
        negotiated_speed_{::int64_t{0}},
        max_speed_{::int64_t{0}},
        transport_id_{::int64_t{0}} {}

template <typename>
constexpr Device::Device(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Device::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Device(arena);
}
constexpr auto Device::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Device), alignof(Device));
}
constexpr auto Device::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &Device::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Device>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Device::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Device>(), &Device::ByteSizeLong,
              &Device::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Device, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DeviceGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DeviceGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Device_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Device::InternalGenerateClassData_(
            _default, &Device_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Device>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DeviceGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Device _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Device>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DeviceGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DeviceGlobalsTypeInternal Device_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Device_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Device_globals_.GetClassData();
#else
  return Device_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class AdbServerStatus::_Internal {
 public:
  using HasBits = decltype(::std::declval<AdbServerStatus>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_._has_bits_);
};

constexpr AdbServerStatus::ParseTableT_ AdbServerStatus::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_._has_bits_),
      0, // no _extensions_
      9, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294966784,  // skipmap
      offsetof(ParseTableT_, field_entries),
      9,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::AdbServerStatus>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // .adb.proto.AdbServerStatus.UsbBackend usb_backend = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AdbServerStatus, _impl_.usb_backend_), 5>(),
       {8, 5, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_)}},
      // bool usb_backend_forced = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(AdbServerStatus, _impl_.usb_backend_forced_), 7>(),
       {16, 7, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_forced_)}},
      // .adb.proto.AdbServerStatus.MdnsBackend mdns_backend = 3;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AdbServerStatus, _impl_.mdns_backend_), 6>(),
       {24, 6, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_)}},
      // bool mdns_backend_forced = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(AdbServerStatus, _impl_.mdns_backend_forced_), 8>(),
       {32, 8, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_forced_)}},
      // string version = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 0, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.version_)}},
      // string build = 6;
      {::_pbi::TcParser::FastUS1,
       {50, 1, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.build_)}},
      // string executable_absolute_path = 7;
      {::_pbi::TcParser::FastUS1,
       {58, 2, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.executable_absolute_path_)}},
      // string log_absolute_path = 8;
      {::_pbi::TcParser::FastUS1,
       {66, 3, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.log_absolute_path_)}},
      // string os = 9;
      {::_pbi::TcParser::FastUS1,
       {74, 4, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.os_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // .adb.proto.AdbServerStatus.UsbBackend usb_backend = 1;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // bool usb_backend_forced = 2;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_forced_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // .adb.proto.AdbServerStatus.MdnsBackend mdns_backend = 3;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // bool mdns_backend_forced = 4;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_forced_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // string version = 5;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.version_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string build = 6;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.build_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string executable_absolute_path = 7;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.executable_absolute_path_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string log_absolute_path = 8;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.log_absolute_path_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string os = 9;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.os_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\31\0\0\0\0\7\5\30\21\2\0\0\0\0\0\0"
      "adb.proto.AdbServerStatus"
      "version"
      "build"
      "executable_absolute_path"
      "log_absolute_path"
      "os"
    }},
  };
}


inline constexpr AdbServerStatus::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        version_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        build_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        executable_absolute_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        log_absolute_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        os_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        usb_backend_{static_cast< ::adb::proto::AdbServerStatus_UsbBackend >(0)},
        mdns_backend_{static_cast< ::adb::proto::AdbServerStatus_MdnsBackend >(0)},
        usb_backend_forced_{false},
        mdns_backend_forced_{false} {}

template <typename>
constexpr AdbServerStatus::AdbServerStatus(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL AdbServerStatus::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AdbServerStatus(arena);
}
constexpr auto AdbServerStatus::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(AdbServerStatus), alignof(AdbServerStatus));
}
constexpr auto AdbServerStatus::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &AdbServerStatus::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AdbServerStatus>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AdbServerStatus::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AdbServerStatus>(), &AdbServerStatus::ByteSizeLong,
              &AdbServerStatus::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct AdbServerStatusGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr AdbServerStatusGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 AdbServerStatus_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(AdbServerStatus::InternalGenerateClassData_(
            _default, &AdbServerStatus_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<AdbServerStatus>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~AdbServerStatusGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) AdbServerStatus _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<AdbServerStatus>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(AdbServerStatusGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST AdbServerStatusGlobalsTypeInternal AdbServerStatus_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* AdbServerStatus_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return AdbServerStatus_globals_.GetClassData();
#else
  return AdbServerStatus_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class Devices::_Internal {
 public:
  using HasBits = decltype(::std::declval<Devices>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Devices, _impl_._has_bits_);
};

constexpr Devices::ParseTableT_ Devices::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Devices, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::Devices>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated .adb.proto.Device device = 1;
      {::_pbi::TcParser::FastMtR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(Devices, _impl_.device_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated .adb.proto.Device device = 1;
      {PROTOBUF_FIELD_OFFSET(Devices, _impl_.device_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::adb::proto::Device>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::adb::proto::Device_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr Devices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        device_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::Devices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_.device_)>()
         }
     {}

template <typename>
constexpr Devices::Devices(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Devices::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Devices(arena);
}
constexpr auto Devices::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Devices), alignof(Devices));
}
constexpr auto Devices::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &Devices::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Devices>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Devices::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Devices>(), &Devices::ByteSizeLong,
              &Devices::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Devices, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DevicesGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DevicesGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Devices_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Devices::InternalGenerateClassData_(
            _default, &Devices_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Devices>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DevicesGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Devices _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Devices>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DevicesGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DevicesGlobalsTypeInternal Devices_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Devices_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Devices_globals_.GetClassData();
#else
  return Devices_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace proto
}  // namespace adb
static const ::_pb::EnumDescriptor* PROTOBUF_NONNULL
    file_level_enum_descriptors_adb_5fhost_2eproto[4];
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_adb_5fhost_2eproto = nullptr;
const ::uint32_t
    TableStruct_adb_5fhost_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_._has_bits_),
        13, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.serial_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.state_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.bus_address_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.product_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.model_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.device_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.connection_type_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.negotiated_speed_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.max_speed_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.transport_id_),
        0,
        5,
        1,
        2,
        3,
        4,
        6,
        7,
        8,
        9,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_.device_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_._has_bits_),
        12, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.usb_backend_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.usb_backend_forced_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.mdns_backend_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.mdns_backend_forced_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.version_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.build_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.executable_absolute_path_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.log_absolute_path_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.os_),
        5,
        7,
        6,
        8,
        0,
        1,
        2,
        3,
        4,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::adb::proto::Device)},
        {23, sizeof(::adb::proto::Devices)},
        {28, sizeof(::adb::proto::AdbServerStatus)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::adb::proto::Device_globals_,
        &::adb::proto::Devices_globals_,
        &::adb::proto::AdbServerStatus_globals_,
};
const char descriptor_table_protodef_adb_5fhost_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\016adb_host.proto\022\tadb.proto\"\377\001\n\006Device\022\016"
    "\n\006serial\030\001 \001(\t\022)\n\005state\030\002 \001(\0162\032.adb.prot"
    "o.ConnectionState\022\023\n\013bus_address\030\003 \001(\t\022\017"
    "\n\007product\030\004 \001(\t\022\r\n\005model\030\005 \001(\t\022\016\n\006device"
    "\030\006 \001(\t\0222\n\017connection_type\030\007 \001(\0162\031.adb.pr"
    "oto.ConnectionType\022\030\n\020negotiated_speed\030\010"
    " \001(\003\022\021\n\tmax_speed\030\t \001(\003\022\024\n\014transport_id\030"
    "\n \001(\003\",\n\007Devices\022!\n\006device\030\001 \003(\0132\021.adb.p"
    "roto.Device\"\242\003\n\017AdbServerStatus\022:\n\013usb_b"
    "ackend\030\001 \001(\0162%.adb.proto.AdbServerStatus"
    ".UsbBackend\022\032\n\022usb_backend_forced\030\002 \001(\010\022"
    "<\n\014mdns_backend\030\003 \001(\0162&.adb.proto.AdbSer"
    "verStatus.MdnsBackend\022\033\n\023mdns_backend_fo"
    "rced\030\004 \001(\010\022\017\n\007version\030\005 \001(\t\022\r\n\005build\030\006 \001"
    "(\t\022 \n\030executable_absolute_path\030\007 \001(\t\022\031\n\021"
    "log_absolute_path\030\010 \001(\t\022\n\n\002os\030\t \001(\t\"5\n\nU"
    "sbBackend\022\017\n\013UNKNOWN_USB\020\000\022\n\n\006NATIVE\020\001\022\n"
    "\n\006LIBUSB\020\002\"<\n\013MdnsBackend\022\020\n\014UNKNOWN_MDN"
    "S\020\000\022\013\n\007BONJOUR\020\001\022\016\n\nOPENSCREEN\020\002*\310\001\n\017Con"
    "nectionState\022\007\n\003ANY\020\000\022\016\n\nCONNECTING\020\001\022\017\n"
    "\013AUTHORIZING\020\002\022\020\n\014UNAUTHORIZED\020\003\022\020\n\014NOPE"
    "RMISSION\020\004\022\014\n\010DETACHED\020\005\022\013\n\007OFFLINE\020\006\022\016\n"
    "\nBOOTLOADER\020\007\022\n\n\006DEVICE\020\010\022\010\n\004HOST\020\t\022\014\n\010R"
    "ECOVERY\020\n\022\014\n\010SIDELOAD\020\013\022\n\n\006RESCUE\020\014*2\n\016C"
    "onnectionType\022\013\n\007UNKNOWN\020\000\022\007\n\003USB\020\001\022\n\n\006S"
    "OCKET\020\002B-\n\035com.android.server.adb.protos"
    "B\014DevicesProtob\006proto3"
};
static ::absl::once_flag descriptor_table_adb_5fhost_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_adb_5fhost_2eproto = {
    false,
    false,
    1062,
    descriptor_table_protodef_adb_5fhost_2eproto,
    "adb_host.proto",
    &descriptor_table_adb_5fhost_2eproto_once,
    nullptr,
    0,
    3,
    schemas,
    file_message_globals,
    TableStruct_adb_5fhost_2eproto::offsets,
    file_level_enum_descriptors_adb_5fhost_2eproto,
    file_level_service_descriptors_adb_5fhost_2eproto,
};
namespace adb {
namespace proto {
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
AdbServerStatus_UsbBackend_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_adb_5fhost_2eproto);
  return file_level_enum_descriptors_adb_5fhost_2eproto[0];
}
PROTOBUF_CONSTINIT const uint32_t AdbServerStatus_UsbBackend_internal_data_[] = {
    196608u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
AdbServerStatus_MdnsBackend_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_adb_5fhost_2eproto);
  return file_level_enum_descriptors_adb_5fhost_2eproto[1];
}
PROTOBUF_CONSTINIT const uint32_t AdbServerStatus_MdnsBackend_internal_data_[] = {
    196608u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
ConnectionState_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_adb_5fhost_2eproto);
  return file_level_enum_descriptors_adb_5fhost_2eproto[2];
}
PROTOBUF_CONSTINIT const uint32_t ConnectionState_internal_data_[] = {
    851968u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
ConnectionType_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_adb_5fhost_2eproto);
  return file_level_enum_descriptors_adb_5fhost_2eproto[3];
}
PROTOBUF_CONSTINIT const uint32_t ConnectionType_internal_data_[] = {
    196608u, 0u, };
// ===================================================================

Device::Device(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Device_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.Device)
}
PROTOBUF_NDEBUG_INLINE Device::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::Device& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        serial_(arena, from.serial_),
        bus_address_(arena, from.bus_address_),
        product_(arena, from.product_),
        model_(arena, from.model_),
        device_(arena, from.device_) {}

Device::Device(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Device& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Device_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Device* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, state_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, state_),
           offsetof(Impl_, transport_id_) -
               offsetof(Impl_, state_) +
               sizeof(Impl_::transport_id_));

  // @@protoc_insertion_point(copy_constructor:adb.proto.Device)
}
PROTOBUF_NDEBUG_INLINE Device::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        serial_(arena),
        bus_address_(arena),
        product_(arena),
        model_(arena),
        device_(arena) {}

inline void Device::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, state_),
           0,
           offsetof(Impl_, transport_id_) -
               offsetof(Impl_, state_) +
               sizeof(Impl_::transport_id_));
}
Device::~Device() {
  // @@protoc_insertion_point(destructor:adb.proto.Device)
  SharedDtor(*this);
}
inline void Device::SharedDtor(MessageLite& self) {
  Device& this_ = static_cast<Device&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.serial_.Destroy();
  this_._impl_.bus_address_.Destroy();
  this_._impl_.product_.Destroy();
  this_._impl_.model_.Destroy();
  this_._impl_.device_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Device_class_data_ =
        Device::InternalGenerateClassData_(Device_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Device::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Device_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Device_class_data_.tc_table);
  return Device_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Device::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Device_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&Device_globals_));
  return Device_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Device::ParseTableT_
    Device::_table_ =
        Device::InternalGenerateParseTable_(Device_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Device::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.Device)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.serial_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.bus_address_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.product_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.model_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.device_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000e0U)) {
    ::memset(&_impl_.state_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.negotiated_speed_) -
        reinterpret_cast<char*>(&_impl_.state_)) + sizeof(_impl_.negotiated_speed_));
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    ::memset(&_impl_.max_speed_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.transport_id_) -
        reinterpret_cast<char*>(&_impl_.max_speed_)) + sizeof(_impl_.transport_id_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Device::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Device& this_ = static_cast<const Device&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Device::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Device& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.Device)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string serial = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_serial().empty()) {
      const ::std::string& _s = this_._internal_serial();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.serial");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // .adb.proto.ConnectionState state = 2;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_state() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          2, this_._internal_state(), target);
    }
  }

  // string bus_address = 3;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_bus_address().empty()) {
      const ::std::string& _s = this_._internal_bus_address();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.bus_address");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  // string product = 4;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_product().empty()) {
      const ::std::string& _s = this_._internal_product();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.product");
      target = stream->WriteStringMaybeAliased(4, _s, target);
    }
  }

  // string model = 5;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_model().empty()) {
      const ::std::string& _s = this_._internal_model();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.model");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string device = 6;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (!this_._internal_device().empty()) {
      const ::std::string& _s = this_._internal_device();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.device");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // .adb.proto.ConnectionType connection_type = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_connection_type() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          7, this_._internal_connection_type(), target);
    }
  }

  // int64 negotiated_speed = 8;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_negotiated_speed() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<8>(
              stream, this_._internal_negotiated_speed(), target);
    }
  }

  // int64 max_speed = 9;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_max_speed() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<9>(
              stream, this_._internal_max_speed(), target);
    }
  }

  // int64 transport_id = 10;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (this_._internal_transport_id() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<10>(
              stream, this_._internal_transport_id(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.Device)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Device::ByteSizeLong(const MessageLite& base) {
  const Device& this_ = static_cast<const Device&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Device::ByteSizeLong() const {
  const Device& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.Device)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string serial = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_serial().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_serial());
      }
    }
    // string bus_address = 3;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_bus_address().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_bus_address());
      }
    }
    // string product = 4;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_product().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_product());
      }
    }
    // string model = 5;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_model().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_model());
      }
    }
    // string device = 6;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!this_._internal_device().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_device());
      }
    }
    // .adb.proto.ConnectionState state = 2;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_state() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_state());
      }
    }
    // .adb.proto.ConnectionType connection_type = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_connection_type() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_connection_type());
      }
    }
    // int64 negotiated_speed = 8;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_negotiated_speed() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_negotiated_speed());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    // int64 max_speed = 9;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_max_speed() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_max_speed());
      }
    }
    // int64 transport_id = 10;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (this_._internal_transport_id() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_transport_id());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Device::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Device*>(&to_msg);
  auto& from = static_cast<const Device&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.Device)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_serial().empty()) {
        _this->_internal_set_serial(from._internal_serial());
      } else {
        if (_this->_impl_.serial_.IsDefault()) {
          _this->_internal_set_serial("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_bus_address().empty()) {
        _this->_internal_set_bus_address(from._internal_bus_address());
      } else {
        if (_this->_impl_.bus_address_.IsDefault()) {
          _this->_internal_set_bus_address("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_product().empty()) {
        _this->_internal_set_product(from._internal_product());
      } else {
        if (_this->_impl_.product_.IsDefault()) {
          _this->_internal_set_product("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_model().empty()) {
        _this->_internal_set_model(from._internal_model());
      } else {
        if (_this->_impl_.model_.IsDefault()) {
          _this->_internal_set_model("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!from._internal_device().empty()) {
        _this->_internal_set_device(from._internal_device());
      } else {
        if (_this->_impl_.device_.IsDefault()) {
          _this->_internal_set_device("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_state() != 0) {
        _this->_impl_.state_ = from._impl_.state_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_connection_type() != 0) {
        _this->_impl_.connection_type_ = from._impl_.connection_type_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_negotiated_speed() != 0) {
        _this->_impl_.negotiated_speed_ = from._impl_.negotiated_speed_;
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (from._internal_max_speed() != 0) {
        _this->_impl_.max_speed_ = from._impl_.max_speed_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (from._internal_transport_id() != 0) {
        _this->_impl_.transport_id_ = from._impl_.transport_id_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Device::CopyFrom(const Device& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.Device)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Device::InternalSwap(Device* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.serial_, &other->_impl_.serial_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.bus_address_, &other->_impl_.bus_address_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.product_, &other->_impl_.product_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.model_, &other->_impl_.model_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.device_, &other->_impl_.device_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Device, _impl_.transport_id_)
      + sizeof(Device::_impl_.transport_id_)
      - PROTOBUF_FIELD_OFFSET(Device, _impl_.state_)>(
          reinterpret_cast<char*>(&_impl_.state_),
          reinterpret_cast<char*>(&other->_impl_.state_));
}

::google::protobuf::Metadata Device::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

Devices::Devices(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Devices_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.Devices)
}
PROTOBUF_NDEBUG_INLINE Devices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::Devices& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        device_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::adb::proto::Devices,
              PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_.device_)>()
          , from.device_
        }
     {}

Devices::Devices(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Devices& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Devices_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Devices* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:adb.proto.Devices)
}
PROTOBUF_NDEBUG_INLINE Devices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        device_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::Devices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_.device_)>()
         }
     {}

inline void Devices::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
Devices::~Devices() {
  // @@protoc_insertion_point(destructor:adb.proto.Devices)
  SharedDtor(*this);
}
inline void Devices::SharedDtor(MessageLite& self) {
  Devices& this_ = static_cast<Devices&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Devices_class_data_ =
        Devices::InternalGenerateClassData_(Devices_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Devices::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Devices_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Devices_class_data_.tc_table);
  return Devices_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Devices::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Devices_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&Devices_globals_));
  return Devices_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Devices::ParseTableT_
    Devices::_table_ =
        Devices::InternalGenerateParseTable_(Devices_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Devices::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.Devices)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.device_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Devices::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Devices& this_ = static_cast<const Devices&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Devices::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Devices& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.Devices)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .adb.proto.Device device = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_device_size());
         i < n; i++) {
      const auto& repfield = this_._internal_device().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              1, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.Devices)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Devices::ByteSizeLong(const MessageLite& base) {
  const Devices& this_ = static_cast<const Devices&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Devices::ByteSizeLong() const {
  const Devices& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.Devices)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .adb.proto.Device device = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_device_size();
      for (const auto& msg : this_._internal_device()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Devices::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Devices*>(&to_msg);
  auto& from = static_cast<const Devices&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.Devices)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_device()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_device());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Devices::CopyFrom(const Devices& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.Devices)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Devices::InternalSwap(Devices* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.device_.InternalSwap(&other->_impl_.device_);
}

::google::protobuf::Metadata Devices::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

AdbServerStatus::AdbServerStatus(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AdbServerStatus_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.AdbServerStatus)
}
PROTOBUF_NDEBUG_INLINE AdbServerStatus::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::AdbServerStatus& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        version_(arena, from.version_),
        build_(arena, from.build_),
        executable_absolute_path_(arena, from.executable_absolute_path_),
        log_absolute_path_(arena, from.log_absolute_path_),
        os_(arena, from.os_) {}

AdbServerStatus::AdbServerStatus(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AdbServerStatus& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AdbServerStatus_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AdbServerStatus* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, usb_backend_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, usb_backend_),
           offsetof(Impl_, mdns_backend_forced_) -
               offsetof(Impl_, usb_backend_) +
               sizeof(Impl_::mdns_backend_forced_));

  // @@protoc_insertion_point(copy_constructor:adb.proto.AdbServerStatus)
}
PROTOBUF_NDEBUG_INLINE AdbServerStatus::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        version_(arena),
        build_(arena),
        executable_absolute_path_(arena),
        log_absolute_path_(arena),
        os_(arena) {}

inline void AdbServerStatus::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, usb_backend_),
           0,
           offsetof(Impl_, mdns_backend_forced_) -
               offsetof(Impl_, usb_backend_) +
               sizeof(Impl_::mdns_backend_forced_));
}
AdbServerStatus::~AdbServerStatus() {
  // @@protoc_insertion_point(destructor:adb.proto.AdbServerStatus)
  SharedDtor(*this);
}
inline void AdbServerStatus::SharedDtor(MessageLite& self) {
  AdbServerStatus& this_ = static_cast<AdbServerStatus&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.version_.Destroy();
  this_._impl_.build_.Destroy();
  this_._impl_.executable_absolute_path_.Destroy();
  this_._impl_.log_absolute_path_.Destroy();
  this_._impl_.os_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AdbServerStatus_class_data_ =
        AdbServerStatus::InternalGenerateClassData_(AdbServerStatus_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AdbServerStatus::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AdbServerStatus_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AdbServerStatus_class_data_.tc_table);
  return AdbServerStatus_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AdbServerStatus::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AdbServerStatus_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&AdbServerStatus_globals_));
  return AdbServerStatus_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const AdbServerStatus::ParseTableT_
    AdbServerStatus::_table_ =
        AdbServerStatus::InternalGenerateParseTable_(AdbServerStatus_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void AdbServerStatus::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.AdbServerStatus)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.version_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.build_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.executable_absolute_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.log_absolute_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.os_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000e0U)) {
    ::memset(&_impl_.usb_backend_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.usb_backend_forced_) -
        reinterpret_cast<char*>(&_impl_.usb_backend_)) + sizeof(_impl_.usb_backend_forced_));
  }
  _impl_.mdns_backend_forced_ = false;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AdbServerStatus::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AdbServerStatus& this_ = static_cast<const AdbServerStatus&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AdbServerStatus::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AdbServerStatus& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.AdbServerStatus)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .adb.proto.AdbServerStatus.UsbBackend usb_backend = 1;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_usb_backend() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          1, this_._internal_usb_backend(), target);
    }
  }

  // bool usb_backend_forced = 2;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_usb_backend_forced() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          2, this_._internal_usb_backend_forced(), target);
    }
  }

  // .adb.proto.AdbServerStatus.MdnsBackend mdns_backend = 3;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_mdns_backend() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          3, this_._internal_mdns_backend(), target);
    }
  }

  // bool mdns_backend_forced = 4;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_mdns_backend_forced() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          4, this_._internal_mdns_backend_forced(), target);
    }
  }

  // string version = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_version().empty()) {
      const ::std::string& _s = this_._internal_version();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.version");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string build = 6;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_build().empty()) {
      const ::std::string& _s = this_._internal_build();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.build");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // string executable_absolute_path = 7;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_executable_absolute_path().empty()) {
      const ::std::string& _s = this_._internal_executable_absolute_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.executable_absolute_path");
      target = stream->WriteStringMaybeAliased(7, _s, target);
    }
  }

  // string log_absolute_path = 8;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_log_absolute_path().empty()) {
      const ::std::string& _s = this_._internal_log_absolute_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.log_absolute_path");
      target = stream->WriteStringMaybeAliased(8, _s, target);
    }
  }

  // string os = 9;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (!this_._internal_os().empty()) {
      const ::std::string& _s = this_._internal_os();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.os");
      target = stream->WriteStringMaybeAliased(9, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.AdbServerStatus)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AdbServerStatus::ByteSizeLong(const MessageLite& base) {
  const AdbServerStatus& this_ = static_cast<const AdbServerStatus&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AdbServerStatus::ByteSizeLong() const {
  const AdbServerStatus& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.AdbServerStatus)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string version = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_version().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_version());
      }
    }
    // string build = 6;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_build().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_build());
      }
    }
    // string executable_absolute_path = 7;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_executable_absolute_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_executable_absolute_path());
      }
    }
    // string log_absolute_path = 8;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_log_absolute_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_log_absolute_path());
      }
    }
    // string os = 9;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!this_._internal_os().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_os());
      }
    }
    // .adb.proto.AdbServerStatus.UsbBackend usb_backend = 1;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_usb_backend() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_usb_backend());
      }
    }
    // .adb.proto.AdbServerStatus.MdnsBackend mdns_backend = 3;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_mdns_backend() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_mdns_backend());
      }
    }
    // bool usb_backend_forced = 2;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_usb_backend_forced() != 0) {
        total_size += 2;
      }
    }
  }
   {
    // bool mdns_backend_forced = 4;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_mdns_backend_forced() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AdbServerStatus::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<AdbServerStatus*>(&to_msg);
  auto& from = static_cast<const AdbServerStatus&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.AdbServerStatus)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_version().empty()) {
        _this->_internal_set_version(from._internal_version());
      } else {
        if (_this->_impl_.version_.IsDefault()) {
          _this->_internal_set_version("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_build().empty()) {
        _this->_internal_set_build(from._internal_build());
      } else {
        if (_this->_impl_.build_.IsDefault()) {
          _this->_internal_set_build("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_executable_absolute_path().empty()) {
        _this->_internal_set_executable_absolute_path(from._internal_executable_absolute_path());
      } else {
        if (_this->_impl_.executable_absolute_path_.IsDefault()) {
          _this->_internal_set_executable_absolute_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_log_absolute_path().empty()) {
        _this->_internal_set_log_absolute_path(from._internal_log_absolute_path());
      } else {
        if (_this->_impl_.log_absolute_path_.IsDefault()) {
          _this->_internal_set_log_absolute_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!from._internal_os().empty()) {
        _this->_internal_set_os(from._internal_os());
      } else {
        if (_this->_impl_.os_.IsDefault()) {
          _this->_internal_set_os("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_usb_backend() != 0) {
        _this->_impl_.usb_backend_ = from._impl_.usb_backend_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_mdns_backend() != 0) {
        _this->_impl_.mdns_backend_ = from._impl_.mdns_backend_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_usb_backend_forced() != 0) {
        _this->_impl_.usb_backend_forced_ = from._impl_.usb_backend_forced_;
      }
    }
  }
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (from._internal_mdns_backend_forced() != 0) {
      _this->_impl_.mdns_backend_forced_ = from._impl_.mdns_backend_forced_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void AdbServerStatus::CopyFrom(const AdbServerStatus& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.AdbServerStatus)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AdbServerStatus::InternalSwap(AdbServerStatus* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.version_, &other->_impl_.version_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.build_, &other->_impl_.build_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.executable_absolute_path_, &other->_impl_.executable_absolute_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.log_absolute_path_, &other->_impl_.log_absolute_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.os_, &other->_impl_.os_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_forced_)
      + sizeof(AdbServerStatus::_impl_.mdns_backend_forced_)
      - PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_)>(
          reinterpret_cast<char*>(&_impl_.usb_backend_),
          reinterpret_cast<char*>(&other->_impl_.usb_backend_));
}

::google::protobuf::Metadata AdbServerStatus::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace proto
}  // namespace adb
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_adb_5fhost_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
